@@ -1,6 +1,7 @@
 
 //#include <sthead.hh>
 #include <cdsMath.hh>
+#include <cstdlib> // for std::abs
 
 namespace CDS {
 
@@ -25,7 +26,7 @@ ipow(const T&  x,
    - works for negative integers too*/
 {
  T temp = 1;
- for (int cnt=0 ; cnt<abs(i) ; cnt++) temp *= x;
+ for (int cnt=0 ; cnt<std::abs(i) ; cnt++) temp *= x;
 
  if (i<0 && temp != 0.0) temp = 1.0 / temp;
 
