@@ -40,6 +40,7 @@ static ToshibaID idList[] = {
   {0xfc61  ,"Tecra 8200 PT8200U"},
   {0xfc63  ,"Tecra 9000"},
   {0xfc64  ,"Satellite 1800-S253"},
+  {0xfc67  ,"Portege 4000"},
   {0xfc68  ,"Satellite PS287A, 2805-s503"},
   {0xfc69  ,"T1900C"},
   {0xfc6a  ,"T1900"},
@@ -119,6 +120,7 @@ static ToshibaID idList[] = {
   {0xfcec  ,"Satellite 320x/330x, Satellite 2500CDS"},
   {0xfced  ,"Tecra 520x/530x"},
   {0xfcef  ,"Satellite 220x, Satellite Pro 440x/460x"},
+  {0xfcf1  ,"Tecra M1"},
   {0xfcf3  ,"Satellite 2450"},
   {0xfcf5  ,"Satellite 5200-903"},
   {0xfcf6  ,"R100"},
