@@ -20,7 +20,7 @@
  *
  */
 
-static char const rcsid[]="$Id: toshset.cc,v 1.41 2005/06/25 19:57:40 schwitrs Exp $";
+static char const rcsid[]="$Id: toshset.cc,v 1.42 2005/10/10 02:59:35 schwitrs Exp $";
 static char const rcsversion[]="$State: Exp $";
 
 
@@ -603,10 +603,12 @@ PercentFeature::query(OStringStream& os) const
 {
  SMMRegisters reg;
  reg.ebx = sciMode;
- SciGet( &reg );
- int percent = ((100*reg.ecx)/reg.edx);
- os << name << ": " << percent << "\% " << ends;
- return 0;
+ int ret = SciGet( &reg );
+ if ( ret == SCI_SUCCESS ) {
+   int percent = ((100*reg.ecx)/reg.edx);
+   os << name << ": " << percent << "\% " << ends;
+ }
+ return ret;
 } /* Feature::action */
 
 
@@ -876,7 +878,7 @@ BlueToothFeature::action(const char** c) const
    return ret;
  }
  if (!(reg.ecx & 0x0f)) {
-   cerr << "Wireless unavailable\n";
+   cerr << "Bluetooth unavailable\n";
    return ret;
  }
  reg.eax = HCI_GET;
@@ -976,7 +978,7 @@ BlueToothFeature::query(OStringStream& os) const
    return ret;
  }
  if (!(reg.ecx & 0x0f)) {
-   cerr << "Wireless unavailable\n";
+   cerr << "Bluetooth unavailable\n";
    return ret;
  }
  reg.eax = HCI_GET;
@@ -1811,6 +1813,16 @@ main(      int   argc,
  PercentFeature batteryPercentFeature(SCI_BATTERY_PERCENT,"battery percent");
  features.append(&batteryPercentFeature);
 
+ PercentFeature secBatteryPercentFeature(SCI_2ND_BATTERY,
+					 "second battery");
+ features.append(&secBatteryPercentFeature);
+
+// PercentFeature secBatteryPercentFeature(SCI_2ND_BATTERY,"second battery");
+// secBatFeature.addValue("disable" , 0 , "disabled");
+// secBatFeature.addValue("enable"  , 1 , "enabled");
+// secBatFeature.addValue("enable"  , 65 , "present");
+// features.append(&secBatFeature);
+
  SciFeature coolingFeature(SCI_COOLING_METHOD,"cooling method");
  coolingFeature.addValue( "perform"   , SCI_PERFORMANCE	  , "performance");
  coolingFeature.addValue( "quiet"     , SCI_QUIET  	  , "quiet");
@@ -1840,10 +1852,6 @@ main(      int   argc,
  // parallelFeature.addValue
  features.append(&parallelFeature);
 
- SciFeature secBatFeature(SCI_2ND_BATTERY,"second battery");
- secBatFeature.addValue("disable" , 0 , "disabled");
- secBatFeature.addValue("enable"  , 1 , "enabled");
- features.append(&secBatFeature);
 
  SciFeature standbyFeature(SCI_STANDBY_TIME,"Standby time");
  features.append(&standbyFeature);
